/*  This file is part of the OPIE libraries
    Copyright (C) 2002 Robert Griebl (sandman@handhelds.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef _LIBOPIE_ODEVICE_H_
#define _LIBOPIE_ODEVICE_H_

#include <qobject.h>
#include <qstring.h>
#include <qnamespace.h>

#include "odevicebutton.h"

#include <qpe/qpeapplication.h> /* for Transformation enum.. */

class ODeviceData;

namespace Opie {

/**
 * The available devices
 */
enum OModel {
        Model_Unknown, // = 0

	Model_Series_Mask   = 0xff000000,

	Model_iPAQ          = ( 1 << 24 ),

	Model_iPAQ_All      = ( Model_iPAQ | 0xffffff ),
	Model_iPAQ_H31xx    = ( Model_iPAQ | 0x000001 ),
	Model_iPAQ_H36xx    = ( Model_iPAQ | 0x000002 ),
	Model_iPAQ_H37xx    = ( Model_iPAQ | 0x000004 ),
	Model_iPAQ_H38xx    = ( Model_iPAQ | 0x000008 ),
	Model_iPAQ_H39xx    = ( Model_iPAQ | 0x000010 ),

	Model_Zaurus        = ( 2 << 24 ),

	Model_Zaurus_SL5000 = ( Model_Zaurus | 0x000001 ),
	Model_Zaurus_SL5500 = ( Model_Zaurus | 0x000002 ),
	Model_Zaurus_SLA300 = ( Model_Zaurus | 0x000003 ),
	Model_Zaurus_SLB600 = ( Model_Zaurus | 0x000004 ),
	Model_Zaurus_SLC700 = ( Model_Zaurus | 0x000005 ),

	Model_SIMpad        = ( 3 << 24 ),

	Model_SIMpad_All    = ( Model_SIMpad | 0xffffff ),
	Model_SIMpad_CL4    = ( Model_SIMpad | 0x000001 ),
	Model_SIMpad_SL4    = ( Model_SIMpad | 0x000002 ),
	Model_SIMpad_SLC    = ( Model_SIMpad | 0x000004 ),
	Model_SIMpad_TSinus = ( Model_SIMpad | 0x000008 ),
};

/**
 * The vendor of the device
 */
enum OVendor {
	Vendor_Unknown,

	Vendor_HP,
	Vendor_Sharp,
	Vendor_SIEMENS,
};

/**
 * The System used
 */
enum OSystem {
	System_Unknown,

	System_Familiar,
	System_Zaurus,
	System_OpenZaurus
};

/**
 * A singleton which gives informations about device specefic option
 * like the Hardware used, LEDs, the Base Distribution and
 * hardware key mappings.
 *
 *
 * @short A small class for device specefic options
 * @see QObject
 * @author Robert Griebl
 * @version 1.0
 */
class ODevice : public QObject {
	Q_OBJECT

private:
        /* disable copy */
	ODevice ( const ODevice & );

protected:
	ODevice ( );
	virtual void init ( );

	ODeviceData *d;

public:
    // sandman do we want to allow destructions? -zecke?
	virtual ~ODevice ( );


	static ODevice *inst ( );

// information

	QString modelString ( ) const;
	OModel model ( ) const;
	inline OModel series ( ) const { return (OModel) ( model ( ) & Model_Series_Mask ); }

	QString vendorString ( ) const;
	OVendor vendor ( ) const;

	QString systemString ( ) const;
	OSystem system ( ) const;

	QString systemVersionString ( ) const;
};

}

#endif
